Django Non Dark Admin
=====================

Disable or enable dark mode user interface in Django admin panel (Django==3.2).

Installation
------------
For install this app run in terminal:
::

    pip install django-non-dark-admin

Configuration
-------------
Add ''django_non_dark_admin'' to your ``INSTALLED_APPS`` settings. This is must be added **BEFORE** ''django.contrib.admin''.

Set ''DISABLE_DARK_MODE = True'' in your settings module to diable dark mode in admin panel user interface.

License
-------
Licensed under BSD license. See `license link`_ in documentation.

.. _license link: LICENSE.rst